<?php

/**
 *
 */
class DocumentsController extends AppController {

/**
 * Add a new document slot via AJAX.
 *
 * @param string $model The model to link the document to e.g. Page
 * @param integer $key Document slot number
 * @param string $type
 * @param string $prefix Used when embedding documents multiple levels deep e.g. Hotel.Room.0.Document 
 * @param string $plugin
 */
	public function ajax_add($model, $key=0, $type='Document', $prefix="", $plugin="") {

		$slotType = str_replace("Document", "", $type);

		if ($prefix == "" || $prefix == "false") {
			$prefix = $slotType;
		}

		if ($slotType == "") {
			$slotType = 'main';
		}

		if ($plugin != "") {
			$this->loadModel($plugin.".".$model); 
		} else {
			$this->loadModel($model); 
		}


		if (isset($this->$model->documentSlots[Inflector::underscore($slotType)])) {
			if (isset($this->$model->documentSlots[Inflector::underscore($slotType)]['fields'])) {
				$fields = $this->$model->documentSlots[Inflector::underscore($slotType)]['fields'];
			} else {
				$fields = true;
			}
		} else {
			$fields = true;
		}

		$this->set(compact('model', 'prefix', 'key', 'type', 'fields'));

		$this->theme = "Admin";

		$this->render('ajax_add', 'ajax');

		return;

	}


/**
 * Removes a document
 *
 * @param int $id file to be removed
 */
	public function ajax_remove($id) {

		// Model name
		$Model = $this->{$this->modelClass}->alias;

		$this->render('../../Admin/Documents/ajax_remove', 'ajax');

		return $this->$Model->delete($id);
		
	}

/**
 * Change the sequence of a document
 *
 * @param int $id file to be reordered
 * @param string $direction direction to reorder, up or down
 */
	public function ajax_reorder($id, $direction='down') {

		// Model name
		$Model = $this->{$this->modelClass}->alias;

		$this->set('model', $Model);

		// Fetch the currenct document
		$currentDocument = $this->$Model->findById($id);

		if (!empty($currentDocument)) {

			// Find the relevant adjacent document

			$direction = $direction=='down' ? '>' : '<';

			$params = array(
				'conditions' => array(
					'id <>' => $id,
					'model' => $currentDocument[$Model]['model'],
					'model_id' => $currentDocument[$Model]['model_id'],
					"sequence $direction" => $currentDocument[$Model]['sequence']
				)
			);

			$adjacentDocument = $this->$Model->find('first', $params);

			if (!empty($adjacentDocument)) {

				// Swap the sequence numbers of the current and adjacent documents

				$data = array(
					array(
						'id' => $id,
						'sequence' => $adjacentDocument[$Model]['sequence']
					),
					array(
						'id' => $adjacentDocument[$Model]['id'],
						'sequence' => $currentDocument[$Model]['sequence']
					)
				);

				$this->$Model->saveMany($data);

			}

			$this->set(compact('currentDocument', 'adjacentDocument'));

		}

		$this->render('../../Admin/Documents/ajax_reorder', 'ajax');

		return;

	}

}